@@ -1,17 +1,21 @@
 # path_alias.py
 """ Handling for URL aliases """
 
+import logging
 import typing
+import urllib.parse
 
 from flask import current_app, redirect, url_for
 from pony import orm
 
-from . import model
+from . import model, user
 
 # redirection types
 PERMANENT = 301
 TEMPORARY = 302
 
+LOGGER = logging.getLogger(__name__)
+
 
 @orm.db_session
 def set_alias(alias: str, alias_type: model.AliasType, **kwargs) -> model.PathAlias:
@@ -33,7 +37,7 @@ def set_alias(alias: str, alias_type: model.AliasType, **kwargs) -> model.PathAl
 
     values = {
         **kwargs,
-        'path': path,
+        'path': urllib.parse.unquote(path),
         'alias_type': alias_type.value
     }
 
@@ -115,6 +119,17 @@ class RenderCategory(Disposition):
         self.template = template
 
 
+class AuthFailed(Disposition):
+    """ Disposition that indicates that the pathalias was to an unauthorized entry """
+    # pylint:disable=too-few-public-methods
+
+    def __init__(self, cur_user: user.User, entry: model.Entry, category: str):
+        super().__init__()
+        self.cur_user = cur_user
+        self.entry = entry
+        self.category = category
+
+
 def get_alias(path: str) -> typing.Optional[Disposition]:
     """ Get a path's alias mapping """
 
@@ -122,40 +137,50 @@ def get_alias(path: str) -> typing.Optional[Disposition]:
 
     if not record or (record.entry and not record.entry.visible):
         url, permanent = current_app.test_path_regex(path)
-        if url:
-            return Response(redirect(url, PERMANENT if permanent else TEMPORARY))
-
-        return None
+        LOGGER.debug("regex match: %s %s", url, permanent)
+        return Response(redirect(url, PERMANENT if permanent else TEMPORARY)) if url else None
 
     alias_type = model.AliasType(record.alias_type)
 
-    if record.category:
-        category = record.category.category
-    elif record.entry:
-        category = record.entry.category
-    else:
-        category = ''
-
-    template_name = record.template if record.template != 'index' else None
-
-    if alias_type == model.AliasType.REDIRECT:
-        args = {'category': category} if category else {}
-
-        if record.template or not record.entry:
-            endpoint = 'category'
-            if template_name:
-                args['template'] = template_name
-            if record.entry:
-                args['id'] = record.entry.id
-        else:
-            if record.entry.redirect_url:
-                return Response(redirect(record.entry.redirect_url, PERMANENT))
-            endpoint = 'entry'
-            args['entry_id'] = record.entry.id
-
-        return Response(redirect(url_for(endpoint, **args), PERMANENT))
+    category = (record.category.category if record.category
+                else record.entry.category if record.entry
+                else '')
 
     if record.entry:
-        return RenderEntry(record.entry, category, record.template)
+        if record.entry.auth:
+            LOGGER.debug("entry with auth")
+            cur_user = user.get_active()
+            if not record.entry.is_authorized(cur_user):
+                return AuthFailed(cur_user, record.entry, category)
 
-    return RenderCategory(category, record.template)
+        if record.entry.redirect_url:
+            LOGGER.debug("redirect URL: %s", record.entry.redirect_url)
+            return Response(redirect(record.entry.redirect_url, PERMANENT))
+
+    if alias_type == model.AliasType.MOUNT:
+        LOGGER.debug("mount entry=%s category=%s template=%s",
+                     record.entry, category, record.template)
+
+        if record.entry:
+            return RenderEntry(record.entry, category, record.template)
+
+        return RenderCategory(category, record.template)
+
+    LOGGER.debug("redirect entry=%s category=%s template=%s",
+                 record.entry, category, record.template)
+    args = {'category': category} if category else {}
+
+    if record.template or not record.entry:
+        endpoint = 'category'
+        if record.template and record.template != 'index':
+            args['template'] = record.template
+        if record.entry:
+            args['id'] = record.entry.id
+    else:
+        endpoint = 'entry'
+        args['entry_id'] = record.entry.id
+        if record.entry.slug_text:
+            args['slug_text'] = record.entry.slug_text
+
+    LOGGER.debug("endpoint=%s args=%s", endpoint, args)
+    return Response(redirect(url_for(endpoint, **args), PERMANENT))
